@@ -1,4 +1,3 @@
-from .vram_reserve import reserve_vram, reserve_vram_retry, unreserve_vram
 from .llm import (
     chat,
     chat_stream,
@@ -11,9 +10,6 @@ from .llm import (
 )
 
 __all__ = [
-    reserve_vram,
-    reserve_vram_retry,
-    unreserve_vram,
     chat,
     chat_stream,
     chat_async,
