@@ -36,8 +36,15 @@ def format_content(cwd, potential_paths, conversation_history):
         else ""
     )
 
-def generate_user_task_prompt(conversation_history, cwd, user_input: str, programmer_mode: bool, active_file:str, opened_files: List[str]):
-    if programmer_mode:
+def generate_user_task_prompt(conversation_history, cwd, user_input: str, bot_setting_file:str):
+    # 需要重新读取openedFiles和activeFile
+    with open(bot_setting_file, encoding="utf-8") as f: 
+        bot_setting = json.load(f)
+    folder_context = bot_setting["folderContext"]
+    opened_files = bot_setting["openedFiles"]
+    active_file = bot_setting["activeFile"]
+
+    if folder_context:
         potential_paths = guess_files_in_message(cwd, user_input)
 
         existing_files = get_formatted_filelist_str(cwd, True, 200)
@@ -79,6 +86,8 @@ def dumps_markdown_json(data):
 
 
 
+import re
+
 async def stream_openai_response(conversation_history, start_new_stream):
     """
     异步流式传输 OpenAI 聊天完成响应并处理结构化输出
@@ -111,24 +120,39 @@ async def stream_openai_response(conversation_history, start_new_stream):
                 if start_new_stream["value"]:
                     break  # 退出当前的 async for 循环，进入下一次 while 循环
 
-                # 处理 buffer 中的每一行
-                while "\n" in buffer:
-                    line, buffer = buffer.split("\n", 1)
+                # 处理 buffer 中的内容
+                while buffer:
                     if not in_json_block:
-                        if line.strip().lower().startswith("```json"):
-                            if text_content:
+                        # 查找 JSON 代码块的起始标记
+                        json_start_match = re.search(r"```json", buffer, re.IGNORECASE)
+                        if json_start_match:
+                            # 提取 JSON 代码块之前的文本
+                            text_content += buffer[:json_start_match.start()]
+                            if text_content.strip():
                                 yield ("text", text_content.strip())
                                 text_content = ""
+                            # 进入 JSON 代码块模式
                             in_json_block = True
+                            buffer = buffer[json_start_match.end():]
                         else:
-                            text_content += line + "\n"
+                            # 如果没有找到 JSON 代码块，直接处理为普通文本
+                            text_content += buffer
+                            buffer = ""
                     else:
-                        if line.strip().lower().startswith("```") and in_json_block:
+                        # 查找 JSON 代码块的结束标记
+                        json_end_match = re.search(r"```", buffer)
+                        if json_end_match:
+                            # 提取 JSON 代码块内容
+                            json_block_content += buffer[:json_end_match.start()]
                             yield ("json", json_block_content.strip())
                             json_block_content = ""
                             in_json_block = False
+                            buffer = buffer[json_end_match.end():]
                         else:
-                            json_block_content += line + "\n"
+                            # 如果没有找到结束标记，继续累积 JSON 内容
+                            json_block_content += buffer
+                            buffer = ""
+                    print(".")
 
             # 如果流正常结束，退出 while 循环
             break
@@ -151,14 +175,11 @@ async def stream_openai_response(conversation_history, start_new_stream):
 
 
 async def handle_user_inputs(
-    conversation_history, user_input, cwd, abilities, has_any_tool, bot_setting
+    conversation_history, user_input, cwd, abilities, has_any_tool, bot_setting, bot_setting_file:str
 ):
     no_exit_if_incomplete = bot_setting["systemAbility"]["no_exit_if_incomplete"]
-    programmer_mode = bot_setting["programmerMode"]
     show_tool_results = bot_setting["showToolResults"]
-    opened_files = bot_setting["openedFiles"]
-    active_file = bot_setting["activeFile"]
-
+    
     start_new_stream = {
         "value": False
     }  # 当遇到AI准备执行JSON，即需要新信息的时候，用于强制停止当前stream，减少后续无效的tokens
@@ -171,7 +192,7 @@ async def handle_user_inputs(
         {
             "role": "user",
             "content": generate_user_task_prompt(
-                conversation_history, cwd, user_input, programmer_mode, active_file, opened_files
+                conversation_history, cwd, user_input, bot_setting_file
             ),
         }
     )
