@@ -283,6 +283,8 @@ class ToolExecutor:
                 except Exception as e:
                     print("Execute tool error:", traceback.format_exc())
                     return False, False, traceback.format_exc()
+                if isinstance(result, str):
+                    return True, False, result
                 try:
                     result = json.dumps(result, indent=4, ensure_ascii=False)
                 except:
