@@ -10,7 +10,7 @@ params = utils.params
 def ref_tools(tool_id, workspace_path=None):
     if workspace_path is None:
         workspace_path = params["workspacePath"]
-    tool_base_path = os.path.join(workspace_path, "User/Local/tool")
+    tool_base_path = os.path.join(workspace_path, "User/Local/Tool")
     module_path = os.path.join(tool_base_path, tool_id)
     module_path = os.path.normpath(os.path.abspath(module_path))
 
