@@ -10,7 +10,7 @@ params = utils.params
 def _ref_workflows(workflow_id, workspace_path=None):
     if workspace_path is None:
         workspace_path = params["workspacePath"]
-    tool_base_path = os.path.join(workspace_path, "User/Local/workflow")
+    tool_base_path = os.path.join(workspace_path, "User/Local/Workflow")
     module_path = os.path.join(tool_base_path, workflow_id)
     module_path = os.path.normpath(os.path.abspath(module_path))
 
@@ -32,7 +32,7 @@ def _ref_workflows(workflow_id, workspace_path=None):
         tool = wrapped_func(tool, module_path)
         if tool.__doc__ is None:
             tool.__doc__ = "This tool is used to " + tool.__name__.replace("_", " ") + "."
-        ret_export_tools.push(tool)
+        ret_export_tools.append(tool)
 
     return ret_export_tools
 
