@@ -28,12 +28,12 @@ def get_ui():
 
     for i in range(10):
         try:
-            if by == "file":
+            if by == "File":
                 json_file = params["uiData"]["uiRecord"][match_ui_file]
                 with open(json_file, "r", encoding="utf-8") as f:
                     return json.load(f)
             else:
-                assert by == "workflow"
+                assert by == 'Workflow'
                 return params["uiData"]["uiRecord"][match_ui_file]
         except Exception as e:
             if i == 9:
